Module registry

Module registry 

Structs

EnumRegistryEntry
Registry entry for enums (tagged unions)
ObjectRegistryEntry
Registry entry for app structs (objects)
TableRegistryEntry
Registry entry for persistable structs (tables)
UnionOfTablesRegistryEntry
Registry entry for union of tables

Enums

TypeCategory
Type category for unified type resolution

Statics

ENUM_REGISTRY_ENTRIES
Distributed slice that collects enum entries from all crates
OBJECT_REGISTRY_ENTRIES
Distributed slice that collects object entries from all crates
TABLE_REGISTRY_ENTRIES
Distributed slice that collects table entries from all crates
UNION_OF_TABLES_REGISTRY_ENTRIES
Distributed slice that collects union of tables entries from all crates

Functions

get_all_enum_names
Get all registered enum names
get_all_object_names
Get all registered object names
get_all_table_names
Get all registered table names
get_all_type_names
Get all registered type names across all categories
get_all_union_of_tables_names
Get all registered union of tables names
get_struct_config
Get struct configuration by type name
get_table_config
Get table configuration by type name
get_tagged_union
Get tagged union by type name
get_union_of_tables
Get union of tables by type name
resolve_type_category
Resolve the category of a type by name