Structs
- Enum
Registry Entry - Registry entry for enums (tagged unions)
- Object
Registry Entry - Registry entry for app structs (objects)
- Table
Registry Entry - Registry entry for persistable structs (tables)
- Union
OfTables Registry Entry - Registry entry for union of tables
Enums
- Type
Category - Type category for unified type resolution
Statics
- ENUM_
REGISTRY_ ENTRIES - Distributed slice that collects enum entries from all crates
- OBJECT_
REGISTRY_ ENTRIES - Distributed slice that collects object entries from all crates
- TABLE_
REGISTRY_ ENTRIES - Distributed slice that collects table entries from all crates
- UNION_
OF_ TABLES_ REGISTRY_ ENTRIES - Distributed slice that collects union of tables entries from all crates
Functions
- get_
all_ enum_ names - Get all registered enum names
- get_
all_ object_ names - Get all registered object names
- get_
all_ table_ names - Get all registered table names
- get_
all_ type_ names - Get all registered type names across all categories
- get_
all_ union_ of_ tables_ names - Get all registered union of tables names
- get_
struct_ config - Get struct configuration by type name
- get_
table_ config - Get table configuration by type name
- get_
tagged_ union - Get tagged union by type name
- get_
union_ of_ tables - Get union of tables by type name
- resolve_
type_ category - Resolve the category of a type by name